==> 1.0.3-dev.tar.gz: lib/src/route/route_bottom_sheet.dart <==
part of '../app_route.dart';

/// BottomSheet route builder
typedef BottomSheetRouteBuilder = Future Function(BuildContext context, RouteSettings settings);

/// [AppRoute] of a BottomSheet
class BottomSheetRoute<T> extends AppRoute<T> {
  final BottomSheetRouteBuilder builder;

  BottomSheetRoute.builder(
    Object name, {
    ThemeBuilder? theme,
    SystemUiStyleBuilder systemUiStyle = Application.defaultSystemUiStyle,
    Color? backgroundColor,
    double? elevation,
    ShapeBorder? shape,
    Clip? clipBehavior,
    BoxConstraints? constraints,
    Color? barrierColor,
    bool isScrollControlled = false,
    bool useRootNavigator = false,
    bool isDismissible = true,
    bool enableDrag = true,
    AnimationController? transitionAnimationController,
    required RouteWidgetBuilder builder,
  })  : builder = ((context, settings) => showModalBottomSheet(
            context: context,
            backgroundColor: backgroundColor,
            elevation: elevation,
            shape: shape,
            clipBehavior: clipBehavior,
            constraints: constraints,
            barrierColor: barrierColor,
            isScrollControlled: isScrollControlled,
            useRootNavigator: useRootNavigator,
            isDismissible: isDismissible,
            enableDrag: enableDrag,
            routeSettings: settings,
            transitionAnimationController: transitionAnimationController,
            builder: wrapIfNotNull<WidgetBuilder, ThemeBuilder>(
                item: theme,
                wrap: (child, theme) =>
                    (context) => Theme(data: theme(context, settings), child: Builder(builder: child)),
                child: (context) => AnnotatedRegion<SystemUiOverlayStyle>(
                    value: systemUiStyle(context), child: builder(context, settings.arguments as RouteArgs))))),
        super(name.toString());

  BottomSheetRoute.draggable(
    Object name, {
    double initialChildSize = .6,
    double minChildSize = .2,
    double maxChildSize = 1,
    bool updateInsets = true,
    ThemeBuilder? theme,
    SystemUiStyleBuilder systemUiStyle = Application.defaultSystemUiStyle,
    Color? backgroundColor,
    double? elevation,
    ShapeBorder? shape,
    Clip? clipBehavior,
    Color? barrierColor,
    bool useRootNavigator = false,
    bool isDismissible = true,
    AnimationController? transitionAnimationController,
    required RouteWidgetBuilder builder,
  }) : this.builder(name,
            theme: theme,
            systemUiStyle: systemUiStyle,
            backgroundColor: Colors.transparent,
            elevation: 0,
            shape: null,
            clipBehavior: Clip.none,
            constraints: null,
            barrierColor: barrierColor,
            isScrollControlled: true,
            useRootNavigator: useRootNavigator,
            isDismissible: isDismissible,
            enableDrag: true,
            transitionAnimationController: transitionAnimationController,
            builder: (context, arguments) => FullscreenDraggableBottomSheet(
                initialChildSize: initialChildSize,
                minChildSize: minChildSize,
                maxChildSize: maxChildSize,
                backgroundColor: backgroundColor,
                elevation: elevation,
                shape: shape,
                clipBehavior: clipBehavior,
                updateInsets: updateInsets,
                child: builder(context, arguments)));

  @override
  Future<T> open(BuildContext context, {RouteArgs args = const {}}) {
    final raw = builder(context, RouteSettings(name: name, arguments: args));
    return AppRoute._result(raw);
  }
}

==> 1.0.5-dev.tar.gz: lib/src/route/route_bottom_sheet.dart <==
part of '../app_route.dart';

/// BottomSheet route builder
typedef BottomSheetRouteBuilder = Future Function(BuildContext context, RouteSettings settings);

/// [AppRoute] of a BottomSheet
class BottomSheetRoute<T> extends AppRoute<T> {
  final BottomSheetRouteBuilder builder;

  BottomSheetRoute.builder(
    Object name, {
    ThemeBuilder? theme,
    SystemUiStyleBuilder systemUiStyle = Application.defaultSystemUiStyle,
    Color? backgroundColor,
    double? elevation,
    ShapeBorder? shape,
    Clip? clipBehavior,
    BoxConstraints? constraints,
    Color? barrierColor,
    bool isScrollControlled = false,
    bool useRootNavigator = false,
    bool isDismissible = true,
    bool enableDrag = true,
    AnimationController? transitionAnimationController,
    required RouteWidgetBuilder builder,
  })  : builder = ((context, settings) => showModalBottomSheet(
            context: context,
            backgroundColor: backgroundColor,
            elevation: elevation,
            shape: shape,
            clipBehavior: clipBehavior,
            constraints: constraints,
            barrierColor: barrierColor,
            isScrollControlled: isScrollControlled,
            useRootNavigator: useRootNavigator,
            isDismissible: isDismissible,
            enableDrag: enableDrag,
            routeSettings: settings,
            transitionAnimationController: transitionAnimationController,
            builder: wrapIfNotNull<WidgetBuilder, ThemeBuilder>(
                item: theme,
                wrap: (child, theme) =>
                    (context) => Theme(data: theme(context, settings), child: Builder(builder: child)),
                child: (context) => AnnotatedSystemUIStyle(
                    style: systemUiStyle(context), child: builder(context, settings.arguments as RouteArgs))))),
        super(name.toString());

  BottomSheetRoute.draggable(
    Object name, {
    double initialChildSize = .6,
    double minChildSize = .2,
    double maxChildSize = 1,
    bool updateInsets = true,
    ThemeBuilder? theme,
    SystemUiStyleBuilder systemUiStyle = Application.defaultSystemUiStyle,
    Color? backgroundColor,
    double? elevation,
    ShapeBorder? shape,
    Clip? clipBehavior,
    Color? barrierColor,
    bool useRootNavigator = false,
    bool isDismissible = true,
    AnimationController? transitionAnimationController,
    required RouteWidgetBuilder builder,
  }) : this.builder(name,
            theme: theme,
            systemUiStyle: systemUiStyle,
            backgroundColor: Colors.transparent,
            elevation: 0,
            shape: null,
            clipBehavior: Clip.none,
            constraints: null,
            barrierColor: barrierColor,
            isScrollControlled: true,
            useRootNavigator: useRootNavigator,
            isDismissible: isDismissible,
            enableDrag: true,
            transitionAnimationController: transitionAnimationController,
            builder: (context, arguments) => FullscreenDraggableBottomSheet(
                initialChildSize: initialChildSize,
                minChildSize: minChildSize,
                maxChildSize: maxChildSize,
                backgroundColor: backgroundColor,
                elevation: elevation,
                shape: shape,
                clipBehavior: clipBehavior,
                updateInsets: updateInsets,
                child: builder(context, arguments)));

  @override
  Future<T> open(BuildContext context, {RouteArgs args = const {}}) {
    final raw = builder(context, RouteSettings(name: name, arguments: args));
    return AppRoute._result(raw);
  }
}
